from argparse import ArgumentParser, _SubParsersAction
def list_action_args(parser: _SubParsersAction, std_parser: ArgumentParser) -> _SubParsersAction:
    """
    Add arguments for the list action to a _SubParsersAction[ArgumentParser]
    
    Args:
        parser (_SubParsersAction[ArgumentParser]): The subparser object
        std_parser (argparse.ArgumentParser): The standard parser object
        
    Returns:
        _SubParsersAction[ArgumentParser]: The parsed arguments
    """
    list_parser = parser.add_parser("list", help="List all scans", parents=[std_parser])
    
    optional_group = list_parser.add_argument_group("Optional", "Optional arguments")
    optional_group.add_argument(
        "-v",
        "--verbose",
        action="store_true",
        help="Enable verbose output",
    )
    
    return parser


from argparse import ArgumentParser, _SubParsersAction
def check_action_args(parser: _SubParsersAction, std_parser: ArgumentParser) -> _SubParsersAction:
    """
    Add arguments for the check action to a _SubParsersAction[ArgumentParser]
    
    Args:
        parser (_SubParsersAction[ArgumentParser]): The subparser object
        std_parser (argparse.ArgumentParser): The standard parser object
        
    Returns:
        _SubParsersAction[ArgumentParser]: The parsed arguments
    """
    check_parser = parser.add_parser("check", help="Check the status of a scan", parents=[std_parser])
    
    required_groug = check_parser.add_argument_group("Required", "Required arguments")
    required_groug.add_argument(
        "-s",
        "--scan_id",
        action="store",
        help="Scan ID to check",
        type=int,
        required=True,
    )
    
    optional_group = check_parser.add_argument_group("Optional", "Optional arguments")
    optional_group.add_argument(
        "-v",
        "--verbose",
        action="store_true",
        help="Enable verbose output",
    )
    
    return parser


import os 
from argparse import ArgumentParser, _SubParsersAction
def pause_action_args(parser: _SubParsersAction, std_parser: ArgumentParser) -> _SubParsersAction:
    """
    Add arguments for the pause action to a _SubParsersAction[ArgumentParser]
    
    Args:
        parser (_SubParsersAction[ArgumentParser]): The subparser object
        std_parser (ArgumentParser): The standard parser object
        
    Returns:
        _SubParsersAction[ArgumentParser]: The parsed arguments
    """
    pause_parser = parser.add_parser("pause", help="Pause a scan", parents=[std_parser])
    
    telegram_group = pause_parser.add_argument_group("Telegram", "Telegram options")
    telegram_group.add_argument(
        "-tT",
        "--telegramToken",
        action="store",
        default=os.getenv("TELEGRAM_BOT_TOKEN"),
        help="Telegram bot token (defaults to TELEGRAM_BOT_TOKEN in ~/.env file)",
        type=str,
    )
    telegram_group.add_argument(
        "-tC",
        "--telegramChatID",
        action="store",
        default=os.getenv("TELEGRAM_CHAT_ID"),
        help="Telegram chat ID (defaults to TELEGRAM_CHAT_ID in ~/.env file)",
        type=str,
    )
    
    required_groug = pause_parser.add_argument_group("Required", "Required arguments")
    required_groug.add_argument(
        "-s",
        "--scan_id",
        action="store",
        help="Scan ID to pause",
        type=int,
        required=True,
    )
    
    optional_group = pause_parser.add_argument_group("Optional", "Optional arguments")
    optional_group.add_argument(
        "-t",
        "--time",
        action="store",
        help="Time to pause the scan at (format: YYYY-MM-DD HH:MM)",
        type=str,
    )
    optional_group.add_argument(
        "-v",
        "--verbose",
        action="store_true",
        help="Enable verbose output",
    )
    
    return parser


#
# Nessus CLI
# Copyright (C) <2023>  <Luke Minniear>
#

__title__ = 'lazy_nessus'
__description__ = 'Pause, resume, list, search for, check the status of, or export a Nessus scan. There is also the option to schedule a pause or resume action. Telegram bot support is also included.'
__version__ = '0.2.3'
